# AutoChrome

> 基于 [DrissionPage](https://drissionpage.cn/browser_control/intro/)
> 和 [PyAutoGUI](https://pyautogui.readthedocs.io/en/latest/index.html) 制作的自用 API 封装库，便于实现网页自动化。

## 技术栈

[测试网站](https://httpbin.org/)：
- [Cookies测试](https://httpbin.org/cookies)

